function EasyPet:OnInitialize()
    self.opt = self.db.profile
    
    EasyPetOptionsAnchor = CreateFrame("Frame", "EasyPetOptionsAnchor", UIParent)
    EasyPetOptionsAnchor:SetWidth(50); EasyPetOptionsAnchor:SetHeight(50); EasyPetOptionsAnchor:SetAlpha(0)
    EasyPetOptionsAnchor:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
    EasyPetOptionsAnchor:EnableMouse(false); EasyPetOptionsAnchor:Hide()

    if EasyPetClassCheck() then
        -- LOAD BUTTONS
        EasyPetLoad_PetButtons()
        
        -- THEN SHOW THE CORRECT ONES
        EasyPet_UpdateButtons()

        -- FIX THE SIZE
        for i = 1, 5 do
            local button = getglobal("EasyPetButton"..i)
            button:SetScale(EasyPet.db.profile.Scale)
        end
        
        -- SHOW OR HIDE THE ANCHOR
        if not EasyPet.db.profile.Locked then EasyPetAnchor:EnableMouse(0); EasyPetAnchor:Hide() else EasyPetAnchor:EnableMouse(1); EasyPetAnchor:Show() end
    end
end

function EasyPet:OnEnable()
    self:RegisterEvent("UNIT_HEALTH")
    self:RegisterEvent("SPELL_UPDATE_COOLDOWN")
    self:RegisterEvent("PLAYER_REGEN_ENABLED")
    
    -- OPTIONS MENU
    for varname, val in pairs(EasyPet_Placement.args) do
        if self.opt[varname] then  EasyPet_Placement.args[varname].set(true) end
    end

    EasyPet.options:Register("EasyPetOptionsAnchor",
        'children', function(level, value) EasyPet:PopulateOptions(level, value) end,
        'point', function(parent) return "CENTER", "CENTER" end,
        'dontHook', true
    )
end

function EasyPet:PopulateOptions(level, value)
    if level == 1 then
        EasyPet.options:AddLine('text', "EasyPet", 'isTitle', true)
        EasyPet.options:AddLine('text', "")
        EasyPet.options:AddLine( 'text', "Placement", 'hasArrow', true, 'value', "Placement" )
        EasyPet.options:FeedAceOptionsTable(EasyPet_Drag, 0)
        EasyPet.options:AddLine( 'text', "Scale", 'hasArrow', true, 'value', "Scale" )
        EasyPet.options:AddLine('text', "")
        EasyPet.options:AddLine('text', "Close", 'func', function() EasyPet.options:Close(1) end)

    elseif level == 2 then
        if value == "Placement" then
            EasyPet.options:FeedAceOptionsTable(EasyPet_Placement, 1)
        elseif value == "Scale" then
            EasyPet.options:FeedAceOptionsTable(EasyPet_Scale, 1)
        end
    end
end

EasyPet:RegisterChatCommand("/EasyPet", "/ep", function() EasyPet.options:Open("EasyPetOptionsAnchor") end)

-- RETURN CLASS
function EasyPetClassCheck()
    local _, class = UnitClass("player")
    if class == "WARLOCK" then return true else return false end
end

-- SCALE UPDATE
function EasyPetScale()
    for i = 1, 5 do
        local button = getglobal("EasyPetButton"..i)
        button:SetScale(EasyPet.db.profile.Scale)
    end
end

-- COOLDOWN UPDATE
function EasyPet:SPELL_UPDATE_COOLDOWN()
    if EasyPetClassCheck() then
        if (GetSpellCooldown(EasyDevour) ~= nil and GetSpellCooldown(EasyDevour) > 0) then
            local start, duration, enable = GetSpellCooldown(EasyDevour)
            EasyPetButton1Cooldown:SetCooldown(start, duration)
            EasyPetButton2Cooldown:SetCooldown(start, duration)
            EasyPetButton3Cooldown:SetCooldown(start, duration)
        elseif (GetSpellCooldown(EasySpellLock) ~= nil and GetSpellCooldown(EasySpellLock) > 0) then
            local start, duration, enable = GetSpellCooldown(EasySpellLock)
            EasyPetButton4Cooldown:SetCooldown(start, duration)
        elseif (GetSpellCooldown(EasySeduce) ~= nil and GetSpellCooldown(EasySeduce) > 0) then
            local start, duration, enable = GetSpellCooldown(EasySeduce);
            EasyPetButton5Cooldown:SetCooldown(start, duration);
        elseif (GetSpellCooldown(EasyIntercept) ~= nil and GetSpellCooldown(EasyIntercept) > 0) then
            local start, duration, enable = GetSpellCooldown(EasyIntercept)
            EasyPetButton8Cooldown:SetCooldown(start, duration)
        end
    end
end

-- UPDATE BUTTONS
local PetFamily = UnitCreatureFamily("pet")
if PetFamily == nil then PetFamily = "Imp" end

function EasyPet_UpdateButtons()
    for i = 1, 8 do
        local button = getglobal("EasyPetButton"..i)
        if button then button:SetAlpha(0); button:EnableMouse(false) end
    end
    
    if (PetFamily == EasyFelhunter) then
        EasyPetButton1:SetAlpha(1); EasyPetButton1:EnableMouse(true)
        EasyPetButton2:SetAlpha(1); EasyPetButton2:EnableMouse(true)
        EasyPetButton3:SetAlpha(1); EasyPetButton3:EnableMouse(true)
        EasyPetButton4:SetAlpha(1); EasyPetButton4:EnableMouse(true)
    elseif (PetFamily == EasySuccubus) then
        EasyPetButton5:SetAlpha(1); EasyPetButton5:EnableMouse(true)
    elseif (PetFamily == EasyVoid) then
        EasyPetButton6:SetAlpha(1); EasyPetButton6:EnableMouse(true)
        EasyPetButton7:SetAlpha(1); EasyPetButton7:EnableMouse(true)
    elseif (PetFamily == EasyFelguard) then
        EasyPetButton8:SetAlpha(1); EasyPetButton8:EnableMouse(true)
    end
    
    EasyPetScale()
end

function EasyPet:UNIT_HEALTH()
    if EasyPetClassCheck() then
        if IsMounted() then return end
        if (UnitCreatureFamily("pet") == PetFamily) then return end
        if UnitCreatureFamily("pet") then PetFamily = UnitCreatureFamily("pet") end
        
        if not UnitAffectingCombat("player") then
            EasyPet_UpdateButtons()
        end
    end
end

function EasyPet:PLAYER_REGEN_ENABLED()
    if EasyPetClassCheck() then
        if not UnitAffectingCombat("player") then
            EasyPet_UpdateButtons()
        end
    end
end